pub struct ManifestChunk<'a> {Show 13 fields
pub key: Cow<'a, str>,
pub contents: Cow<'a, [u8]>,
pub hash: Cow<'a, str>,
pub mime_type: Cow<'a, str>,
pub src: Option<Cow<'a, str>>,
pub file: Cow<'a, str>,
pub css: Cow<'a, [Cow<'a, str>]>,
pub assets: Cow<'a, [Cow<'a, str>]>,
pub is_entry: bool,
pub name: Option<Cow<'a, str>>,
pub is_dynamic_entry: bool,
pub imports: Cow<'a, [Cow<'a, str>]>,
pub dynamic_imports: Cow<'a, [Cow<'a, str>]>,
}Expand description
Vite manifest chunk.
Fields
key: Cow<'a, str>The key of this chunk in manifest.
This field is added by vite-static and skipped during (de)serialization.
contents: Cow<'a, [u8]>The contents of manifest chunk.
This field is added by vite-static and skipped during (de)serialization.
hash: Cow<'a, str>Hash of this chunk. Derive macro uses BLAKE3 as hashing algorithm.
This field is added by vite-static and skipped during (de)serialization.
mime_type: Cow<'a, str>Mime type of this chunk.
This field is added by vite-static and skipped during (de)serialization.
src: Option<Cow<'a, str>>The input file name of this chunk/asset if known.
file: Cow<'a, str>The output file name of this chunk/asset.
css: Cow<'a, [Cow<'a, str>]>The list of CSS files imported by this chunk.
assets: Cow<'a, [Cow<'a, str>]>The list of asset files imported by this chunk, excluding CSS files.
is_entry: boolWhether this chunk or asset is an entry point
name: Option<Cow<'a, str>>The name of this chunk/asset if known.
is_dynamic_entry: boolWhether this chunk is a dynamic entry point
This field is only present in JS chunks.
imports: Cow<'a, [Cow<'a, str>]>The list of statically imported chunks by this chunk
The values are the keys of the manifest. This field is only present in JS chunks.
dynamic_imports: Cow<'a, [Cow<'a, str>]>The list of dynamically imported chunks by this chunk
The values are the keys of the manifest. This field is only present in JS chunks.